@@ -380,8 +380,13 @@ static std::string get_signal_wrap_statements(std::string& includeMacroCalls,
         // wrapper.
         if(g_type_is_a(returnGType, G_TYPE_BOXED))
         {
+          G_GNUC_BEGIN_IGNORE_DEPRECATIONS // temporary disable deprecations because of G_TYPE_VALUE_ARRAY
           // Unwrapping conversion:
-          std::string access_operator = (returnGType != G_TYPE_VALUE_ARRAY && returnGType != GST_TYPE_TAG_LIST) ? "->" : ".";
+          std::string access_operator = (returnGType != G_TYPE_ARRAY &&
+                                         returnGType != G_TYPE_VALUE_ARRAY &&
+                                         returnGType != GST_TYPE_TAG_LIST &&
+                                         returnGType != GST_TYPE_STRUCTURE) ? "->" : ".";
+          G_GNUC_END_IGNORE_DEPRECATIONS
           // For GValueArray and TagList, RefPtr is not generated, and we need to use '.' operator.
           convertMacros += "#m4 _CONVERSION(_LQ()" + returnCTypeTranslation +
             "_RQ(), ``" + returnCType + "'', ``($3)" + access_operator + "gobj_copy()'')\n";
@@ -652,6 +657,7 @@ static void generate_hg_file(const std::string& includeMacroCalls,
     "otherwise there will\n * be errors and possibly a crash." << std::endl;
   std::cout << " *" << std::endl;
   std::cout << " * @ingroup " << nmspace << "Plugins" << std::endl;
+  std::cout << " * @deprecated Plugins API is deprecated, and should not be used in a new code." << std::endl;
   std::cout << " */" << std::endl;
   std::cout << "class " << cppTypeName << std::endl;
   std::cout << ": public " << parentNameSpace << "::" << cppParentTypeName;
@@ -670,8 +676,6 @@ static void generate_hg_file(const std::string& includeMacroCalls,
     std::cout << interfaceMacros << std::endl;
 
   std::cout << "  _IS_GSTREAMERMM_PLUGIN" << std::endl;
-  std::cout << "  _NO_WRAP_INIT_REGISTRATION" << std::endl;
-  std::cout << "  _CUSTOM_WRAP_FUNCTION" << std::endl << std::endl;
 
   std::cout << "protected:" << std::endl;
   std::cout << "  " << cppTypeName << "();" << std::endl;
@@ -737,9 +741,6 @@ static void generate_ccg_file(const std::string& enumGTypeFunctionDefinitions,
   std::cout << "      factory = GST_ELEMENT_FACTORY(feature);" << std::endl;
   std::cout << "      type = gst_element_factory_get_element_type(factory);" << std::endl;
   std::cout << "      g_object_unref(factory);" << std::endl;
-  std::cout << std::endl;
-  std::cout << "      // Register the new type with wrapping system" << std::endl;
-  std::cout << "      Glib::wrap_register(type, &" << nmspace << "::" << cppTypeName << "_Class::wrap_new);" << std::endl;
   std::cout << "    }" << std::endl;
   std::cout << "  }" << std::endl << std::endl;
 
@@ -764,26 +765,6 @@ static void generate_ccg_file(const std::string& enumGTypeFunctionDefinitions,
     std::cout << actionSignalsMethodDefinitions;
 
   std::cout << '}' << std::endl;
-
-  // Generate the custom Glib::wrap() function that pre-registers the
-  // wrap_new() function before calling Glib::wrap_auto().
-  std::string returnType = "Glib::RefPtr<" + (std::string) nmspace + "::" + cppTypeName + ">";
-
-  std::cout << "namespace Glib" << std::endl;
-  std::cout << '{' << std::endl << std::endl;
-  std::cout << returnType << " wrap(" << cTypeName << "* object, bool take_copy)" << std::endl;
-  std::cout << '{' << std::endl;
-  std::cout << "  static bool registered_wrap_new = false;" << std::endl;
-  std::cout << "  if(!registered_wrap_new)" << std::endl;
-  std::cout << "  {" << std::endl;
-  std::cout << "    // Call get *_get_type() function which does the registration." << std::endl;
-  std::cout << "    " << getTypeName << "();" << std::endl;
-  std::cout << "    registered_wrap_new = true;" << std::endl;
-  std::cout << "  }" << std::endl;
-  std::cout << std::endl;
-  std::cout << "  return " << returnType << "( dynamic_cast<" << nmspace << "::" << cppTypeName << "*> (Glib::wrap_auto ((GObject*)(object), take_copy)) );" << std::endl;
-  std::cout << '}' << std::endl << std::endl;
-  std::cout << '}' << std::endl;
 }
 
 } // anonymous namespace
@@ -912,7 +893,7 @@ int main(int argc, char** argv)
       cppParentTypeName.compare("BaseSrc") == 0 ||
       cppParentTypeName.compare("BaseTransform") == 0 ||
       cppParentTypeName.compare("Bin") == 0 ||
-      cppParentTypeName.compare("CddaBaseSrc") == 0 ||
+      cppParentTypeName.compare("AudioCdSrc") == 0 ||
       cppParentTypeName.compare("Element") == 0 ||
       cppParentTypeName.compare("Object") == 0 ||
       cppParentTypeName.compare("Pipeline") == 0 ||
